<?php

namespace Drp\LdapAuthentication;

use Adldap\Laravel\AdldapAuthUserProvider;
use Adldap\Models\User;
use Illuminate\Contracts\Hashing\Hasher;

/**
 * Class DrpldapAuthUserProvider
 * @package  Drp\LdapAuthentication
 */
class DrpldapAuthUserProvider extends AdldapAuthUserProvider
{

    /**
     * @var
     */
    private $allowedGroups;

    /**
     * Create a new database user provider.
     * @param Hasher $hasher
     * @param  string $model
     * @param $allowedGroups
     */
    public function __construct(Hasher $hasher, $model, $allowedGroups)
    {

        $this->model = $model;
        $this->hasher = $hasher;
        $this->allowedGroups = $allowedGroups;

    }

    /**
     * Creates a local User from Active Directory.
     * @param User $user
     * @param string $password
     * @return \Illuminate\Database\Eloquent\Model
     */
    protected function getModelFromAdldap(User $user, $password)
    {

        // Check if the user is in the right group before building the model
        if (!$this->checkLDAPGroups($user)) {
            return;
        }

        return parent::getModelFromAdldap($user, $password);
    }

    /**
     * Check if the specified user is in the specified LDAP group
     * @param $authenticatedUser
     * @return bool
     * @throws LdapGroupException
     */
    private function checkLDAPGroups(User $authenticatedUser)
    {

        //If no groups have been set, skip the check
        if (empty($this->allowedGroups)) {
            return true;
        }

        foreach ($this->allowedGroups as $group) {
            // Check with LDAP if this user has group needed on LDAP
            if ($authenticatedUser->inGroup($group)) {
                return true;
            }
        }

        throw new LdapGroupException('You do not have permission to access this CMS.');

    }

    /**
     * @param mixed $allowedGroups
     */
    public function setAllowedGroups($allowedGroups)
    {
        $this->allowedGroups = $allowedGroups;
    }
}