<?php

namespace Drp\LdapAuthentication;

use Adldap\Laravel\AdldapServiceProvider;
use Illuminate\Support\Facades\Auth;

/**
 * Class DrpldapServiceProvider
 * @package Drp\LdapAuthentication
 */
class DrpldapServiceProvider extends AdldapServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     * @var bool
     */
    protected $defer = false;

    /**
     * Run service provider boot operations.
     * @return void
     */

    public function boot()
    {
        $this->bootLdap();
        $this->bootAuth();
    }

    /**
     *
     */
    protected function bootAuth()
    {
        $auth = __DIR__ . '/../../../adldap2/adldap2-laravel/src/Config/auth.php';

        // Add publishable configuration.
        $this->publishes([
            $auth => config_path('adldap_auth.php'),
        ], 'adldap');

        // Register the adldap auth user provider.
        Auth::provider('adldap', function ($app, array $config) {
            return new DrpldapAuthUserProvider($app['hash'], $config['model'], $app['config']['adldap.allowed_groups']);
        });

    }

    /**
     *
     */
    protected function bootLdap()
    {
        $this->publishes([
            __DIR__ . '/../database/migrations/' => database_path('migrations')
        ], 'migrations');

        $config = __DIR__ . '/../config/config.php';

        $this->publishes([
            $config => config_path('adldap.php'),
        ], 'adldap');

    }

    /**
     * Get the services provided by the provider.
     * @return array
     */
    public function provides()
    {
        return ['auth'];
    }

}